require 'installer/role'

class Installer::Role::Postgres < Installer::Role
  attr_reader :port, :user, :password

  def initialize(config={})
    super(config)
    @port = config[:port] || 5432
    @user = config[:user] || 'root'
    @password = config[:password]
    @database = {}
    @inbound << {role: :console, port: @port}
    @inbound << {role: :puppetdb, port: @port}
    @installed_services << "pe-postgresql"
  end

  def add_database(db_name, database_service)
    @database[db_name] = database_service
  end

  def database(name)
    @database[name]
  end

  def answers_hash
    hash = super({})

    hash.merge!(
      'q_database_host' => @host.hostname,
      'q_database_install' => 'y',
      'q_database_port' => @port,
      'q_database_root_password' => @password,
      'q_database_root_user' => @user,
      'q_pe_database' => 'y'
    )

    if @database.include? 'console'
      hash.merge!(
        'q_puppet_enterpriseconsole_database_name' => @database['console'].name,
        'q_puppet_enterpriseconsole_database_user' => @database['console'].username,
        'q_puppet_enterpriseconsole_database_password' => @database['console'].password
      )
    end

    if @database.include? 'console_auth'
      hash.merge!(
        'q_puppet_enterpriseconsole_auth_database_name' => @database['console_auth'].name,
        'q_puppet_enterpriseconsole_auth_database_user' => @database['console_auth'].username,
        'q_puppet_enterpriseconsole_auth_database_password' => @database['console_auth'].password
      )
    end

    if @database.include? 'puppetdb'
      hash.merge!(
        'q_puppetdb_database_name' => @database['puppetdb'].name,
        'q_puppetdb_database_user' => @database['puppetdb'].username,
        'q_puppetdb_database_password' => @database['puppetdb'].password
      )
    end

    hash
  end

  def name
    :postgres
  end
end
